@@ -37,8 +37,12 @@
  * file under either the MPL or the LGPL.
  */
 
-#ifndef _CANDIDATE_H
-#define _CANDIDATE_H
+#ifndef __LIBNICE_CANDIDATE_H__
+#define __LIBNICE_CANDIDATE_H__
+
+#include "address.h"
+#include <glib.h>
+#include <glib-object.h>
 
 
 /**
@@ -57,19 +61,31 @@
 G_BEGIN_DECLS
 
 
-#define NICE_CANDIDATE_TYPE_PREF_HOST                 120
-#define NICE_CANDIDATE_TYPE_PREF_PEER_REFLEXIVE       110
-#define NICE_CANDIDATE_TYPE_PREF_SERVER_REFLEXIVE     100
-#define NICE_CANDIDATE_TYPE_PREF_RELAYED               60
-
 /* Max foundation size '1*32ice-char' plus terminating NULL, ICE ID-19  */
 /**
  * NICE_CANDIDATE_MAX_FOUNDATION:
  *
  * The maximum size a candidate foundation can have.
  */
-#define NICE_CANDIDATE_MAX_FOUNDATION                32+1
+#define NICE_CANDIDATE_MAX_FOUNDATION                (32+1)
 
+/**
+ * NICE_CANDIDATE_MAX_TURN_SERVERS
+ *
+ * The maximum number of turns servers.
+ */
+#define NICE_CANDIDATE_MAX_TURN_SERVERS              8
+
+/**
+ * NICE_CANDIDATE_MAX_LOCAL_ADDRESSES
+ *
+ * The maximum number of local addresses. The constraint is that the
+ * maximum number of local addresses and number of turn servers must
+ * fit on 9 bits, to ensure candidate priority uniqueness. See also
+ * @NICE_CANDIDATE_MAX_TURN_SERVERS. We choose 6 bits for the number of
+ * local addresses, and 3 bits for the number of turn servers.
+ */
+#define NICE_CANDIDATE_MAX_LOCAL_ADDRESSES           64
 
 /**
  * NiceCandidateType:
@@ -91,12 +107,18 @@ typedef enum
 /**
  * NiceCandidateTransport:
  * @NICE_CANDIDATE_TRANSPORT_UDP: UDP transport
+ * @NICE_CANDIDATE_TRANSPORT_TCP_ACTIVE: TCP Active transport
+ * @NICE_CANDIDATE_TRANSPORT_TCP_PASSIVE: TCP Passive transport
+ * @NICE_CANDIDATE_TRANSPORT_TCP_SO: TCP Simultaneous-Open transport
  *
  * An enum representing the type of transport to use
  */
 typedef enum
 {
   NICE_CANDIDATE_TRANSPORT_UDP,
+  NICE_CANDIDATE_TRANSPORT_TCP_ACTIVE,
+  NICE_CANDIDATE_TRANSPORT_TCP_PASSIVE,
+  NICE_CANDIDATE_TRANSPORT_TCP_SO,
 } NiceCandidateTransport;
 
 /**
@@ -116,24 +138,6 @@ typedef enum {
 
 typedef struct _NiceCandidate NiceCandidate;
 
-typedef struct _TurnServer TurnServer;
-
-/**
- * TurnServer:
- * @server: The #NiceAddress of the TURN server
- * @username: The TURN username
- * @password: The TURN password
- * @type: The #NiceRelayType of the server
- *
- * A structure to store the TURN relay settings
- */
-struct _TurnServer
-{
-  NiceAddress server;       /**< TURN server address */
-  gchar *username;           /**< TURN username */
-  gchar *password;           /**< TURN password */
-  NiceRelayType type;             /**< TURN type */
-};
 
 /**
  * NiceCandidate:
@@ -149,9 +153,6 @@ struct _TurnServer
  * by nice_agent_set_local_credentials() or nice_agent_set_remote_credentials())
  * @password: The candidate-specific password to use (overrides the one set
  * by nice_agent_set_local_credentials() or nice_agent_set_remote_credentials())
- * @turn: The #TurnServer settings if the candidate is
- * of type %NICE_CANDIDATE_TYPE_RELAYED
- * @sockptr: The underlying socket
  *
  * A structure to represent an ICE candidate
  <note>
@@ -173,10 +174,8 @@ struct _NiceCandidate
   guint stream_id;
   guint component_id;
   gchar foundation[NICE_CANDIDATE_MAX_FOUNDATION];
-  gchar *username;        /* pointer to a NULL-terminated username string */
-  gchar *password;        /* pointer to a NULL-terminated password string */
-  TurnServer *turn;
-  gpointer sockptr;
+  gchar *username;        /* pointer to a nul-terminated username string */
+  gchar *password;        /* pointer to a nul-terminated password string */
 };
 
 /**
@@ -210,25 +209,73 @@ nice_candidate_free (NiceCandidate *candidate);
 NiceCandidate *
 nice_candidate_copy (const NiceCandidate *candidate);
 
+/**
+ * nice_candidate_equal_target:
+ * @candidate1: A candidate
+ * @candidate2: A candidate
+ *
+ * Verifies that the candidates point to the same place, meaning they have
+ * the same transport and the same address. It ignores all other aspects.
+ *
+ * Returns: %TRUE if the candidates point to the same place
+ *
+ * Since: 0.1.15
+ */
+gboolean
+nice_candidate_equal_target (const NiceCandidate *candidate1,
+    const NiceCandidate *candidate2);
 
-guint32
-nice_candidate_jingle_priority (NiceCandidate *candidate);
+  GType nice_candidate_get_type (void);
 
-guint32
-nice_candidate_msn_priority (NiceCandidate *candidate);
+/**
+ * nice_candidate_type_to_string:
+ * @type: a #NiceCandidateType
+ *
+ * Useful for debugging functions, just returns a static string with the
+ * candidate type.
+ *
+ * Returns: a static string with the candidate type
+ *
+ * Since: 0.1.19
+ */
+const gchar *
+nice_candidate_type_to_string (NiceCandidateType type);
 
-guint32
-nice_candidate_ice_priority_full (guint type_pref, guint local_pref,
-    guint component_id);
+/**
+ * nice_candidate_transport_to_string:
+ * @transport: a #NiceCandidateTransport
+ *
+ * Useful for debugging functions, just returns a static string with the
+ * candidate transport.
+ *
+ * Returns: a static string with the candidate transport
+ *
+ * Since: 0.1.19
+ */
+const gchar *
+nice_candidate_transport_to_string (NiceCandidateTransport transport);
 
-guint32
-nice_candidate_ice_priority (const NiceCandidate *candidate);
-
-guint64
-nice_candidate_pair_priority (guint32 o_prio, guint32 a_prio);
+/**
+ * nice_candidate_relay_address:
+ * @candidate: A relay candidate
+ * @addr: The #NiceAddress to fill
+ *
+ * In case the given candidate is relayed through a TURN server, use this utility function to get
+ * its address.
+ *
+ * Since: 0.1.19
+ */
+void
+nice_candidate_relay_address (const NiceCandidate *candidate, NiceAddress *addr);
 
+/**
+ * NICE_TYPE_CANDIDATE:
+ *
+ * A boxed type for a #NiceCandidate.
+ */
+#define NICE_TYPE_CANDIDATE nice_candidate_get_type ()
 
 G_END_DECLS
 
-#endif /* _CANDIDATE_H */
+#endif /* __LIBNICE_CANDIDATE_H__ */
 
